@@ -12,9 +12,9 @@ class MatrixBase(object):
     def __getitem__(self, key):
         i,j = key
         if i<0 or i>=self.nrows:
-            raise IndexError()
+            raise IndexError("failed: %d <= i=%s < %d" % (0,i,self.nrows))
         if j<0 or j>=self.ncols:
-            raise IndexError()
+            raise IndexError("failed: %d <= j=%s < %d" % (0,j,self.ncols))
         return self._getitem(i, j)
 
     def _getitem(self, i, j):
@@ -122,6 +122,10 @@ class MatrixRow(MatrixSlice):
     def __setitem__(self, j, val):
         return super(MatrixRow, self).__setitem__((0,j), val)
 
+    def __iter__(self):
+        for j in range(self.ncols):
+            yield self[j]
+
 
 class MatrixCol(MatrixSlice):
 
@@ -133,3 +137,7 @@ class MatrixCol(MatrixSlice):
 
     def __setitem__(self, i, val):
         return super(MatrixCol, self).__setitem__((i,0), val)
+
+    def __iter__(self):
+        for i in range(self.nrows):
+            yield self[i]
